/*
	This do file constructs trade variables at the czone level using CBP employment data. 
	
	Last edited: November 21, 2017
	
*/



set more off
clear all

*Define Directories
local dir "..." //Insert your directory path
local tradedir "`dir'/AGNR-JobFlowsChinaShock/data/trade/"
local cbpdir "`dir'/AGNR-JobFlowsChinaShock/data/cbp/"

*Load trade dataset
use "`tradedir'clean/trade_variables.dta", clear

keep if year>1990

tsset, clear
tsset sic87dd year
sort sic87dd year


foreach t in "7" "8" "12" {

	gen d_import_usch_`t'=(1/`t')*(l_import_usch-L`t'.l_import_usch)
	gen d_import_otch_`t'=(1/`t')*(l_import_otch-L`t'.l_import_otch)*(ratiorm9188)

	foreach d in "us" "ot" {
		foreach v in "up" "down" "up_LT" "down_LT" {
			gen d_`v'_`d'ch_`t'=(1/`t')*(l_import_`v'_`d'ch-L`t'.l_import_`v'_`d'ch)
		}
	}
}	
	
*Generating zeros for direct import penetration measures in non-manufacturing
foreach t in "7" "8" "12" {
	replace d_import_usch_`t'=0 if manuf==0
	replace d_import_otch_`t'=0 if manuf==0
}

keep year sic87dd manuf d*

tempfile import_exposure
save `import_exposure'


**merge in CBP czone-industry employment data and generate czone level import expoure measures **

foreach v in "import" "up" "down" "up_LT" "down_LT" {

		foreach t in "7" "8" "12" {

			use `import_exposure'
			merge 1:m year sic87dd using "`cbpdir'emp_counts/cbp_czone_emp_total.dta", nogenerate
			keep if year > 1990
			rename emp cbp_emp
			
			gen sicczone=string(sic87dd)+string(czone)
			destring sicczone, replace
			tsset sicczone year

			collapse (mean) d_cbp_`v'_cz_usch_`t'=d_`v'_usch_`t' [aw=L`t'.cbp_emp], by(year czone)
			
			tempfile d_cbp_`v'_cz_usch_`t'
			save `d_cbp_`v'_cz_usch_`t''
		}
}


**generate czone level instruments**

foreach v in "import" "up" "down" "up_LT" "down_LT" {

		foreach t in "7" "8" "12" {

			use `import_exposure'
			merge 1:m year sic87dd using "`cbpdir'emp_counts/cbp_czone_emp_total.dta", nogenerate
			rename emp cbp_emp
			
			gen sicczone=string(sic87dd)+string(czone)
			destring sicczone, replace
			tsset sicczone year
			
			*base year for instruments is 1988
			gen cbp_emp1988=cbp_emp
			forvalues i=1989/2011 {
				replace cbp_emp1988=L.cbp_emp1988 if year==`i'
			}

			collapse (mean) d_* [aw=cbp_emp1988], by(year czone)
			keep *otch_7 *otch_8 *otch_12 year czone 
			
			rename d_`v'_otch_`t' d_cbp_`v'_cz_otch_`t'
			
			tempfile d_cbp_`v'_cz_otch_`t'
			save `d_cbp_`v'_cz_otch_`t''
		}
}

* merge all these files
use `d_cbp_import_cz_usch_7', clear
merge 1:1 year czone using `d_cbp_import_cz_usch_8', nogenerate
merge 1:1 year czone using `d_cbp_import_cz_usch_12', nogenerate
merge 1:1 year czone using  `d_cbp_import_cz_otch_7', nogenerate
merge 1:1 year czone using `d_cbp_import_cz_otch_8', nogenerate
merge 1:1 year czone using `d_cbp_import_cz_otch_12', nogenerate

foreach v in "up" "down" "up_LT" "down_LT" {

	foreach t in "7" "8" "12" {
		merge 1:1 year czone using `d_cbp_`v'_cz_usch_`t'', nogenerate
	}
}


foreach v in "up" "down" "up_LT" "down_LT" {

	foreach t in "7" "8" "12" {
		merge 1:1 year czone using `d_cbp_`v'_cz_otch_`t'', nogenerate
	}
}

keep if year > 1990

drop d_import* d_up* d_down* 

save "`tradedir'raw/trade_czone_variables_cbp.dta", replace
