/*
	This do file constructs the share of manufacturing employment in total employment
	using both CBP and NETS data, to be used as a control in the commuting zone level regressions

	Last edited: November 21, 2017
	
*/



set more off
clear all

*Define Directories
local dir "..." //Insert your directory path
local cbpdir "`dir'/AGNR-JobFlowsChinaShock/data/cbp/"
local netsdir "`dir'/AGNR-JobFlowsChinaShock/data/nets/"
local netsdir "`dir'/AGNR-JobFlowsChinaShock/data/controls/"

* Load CBP employment counts
use "`cbpdir'emp_counts/cbp_czone_emp_total.dta", clear
rename emp cbp_emp

* generate manufacturing shares
gen cbp_mfgemp = cbp_emp if sic87dd >= 2000 & sic87dd <= 3999
collapse (sum) cbp_mfgemp cbp_totemp = cbp_emp, by(year czone)
gen cbp_mfgsh=cbp_mfgemp/cbp_totemp
tempfile mfgsh_cbp
save `mfgsh_cbp'

* Load NETS employment counts
use "`netsdir'emp_counts/nets_czone_emp_total.dta", clear

* generate manufacturing shares
gen nets_mfgemp = nets_emp if sic87dd >= 2000 & sic87dd <= 3999
collapse (sum) nets_mfgemp nets_totemp = nets_emp, by(year czone)
gen nets_mfgsh=nets_mfgemp/nets_totemp
tempfile mfgsh_nets
save `mfgsh_nets'

use `mfgsh_cbp', clear
merge 1:1 year czone using `mfgsh_nets', nogenerate
keep *mfgsh year czone

label var cbp_mfgsh "share of manufacturing empolyment in total CBP employment"
label var nets_mfgsh "share of manufacturing empolyment in total NETS employment"

save "`controlsdir'mfgsh.dta", replace
