*************************************************************************
/* TABLE 3: Estimation of the effects of the China Shock on Manufacturing 
Employment by Labor Productivity Terciles */

* Last edited : August 22, 2018
**************************************************************************

set more off
set matsize 1000
clear all

*Define directories
local dir "..." //Insert your directory path
local outdir "`dir'/AGNR-JobFlowsChinaShock/out/"
local datadir "`dir'/AGNR-JobFlowsChinaShock/data/sample/"


*Load dataset
use  "`datadir'main_industry.dta", clear
keep if year < 2012

*Specifying panel
tsset, clear
tsset sic87dd year
sort sic87dd year

*Preparing employment variables
*NETS does not have data for 1991
foreach b in "nets" {
	rename `b'_emp_total `b'_emp
	replace `b'_emp = . if year==1991
}

foreach b in "cbp" "nets"  {

	*log-employment variables
	gen l_`b'_emp=log(`b'_emp)


	foreach t in "7" "8" "12" {
		*log changes
		gen dl_`b'_emp_`t'=(l_`b'_emp-L`t'.l_`b'_emp)*100/`t'
	}
}

*Preparing the NTR gap variable
replace spread=0 if year<2002

*Computing 7, 8 and 12 year differences of the NTR gap variable
foreach t in "7" "8" "12" {
	gen spread_`t' = spread*100/`t'
}



*Job Flows Terciles data
foreach ter in "1" "2" "3"{
	foreach t in "7" "8" "12" {
		gen d_nets_emp_`t'_t`ter' = nets_birth_empchange_`t'_t`ter' - nets_death_empchange_`t'_t`ter' + nets_exp_empchange_`t'_t`ter' - nets_con_empchange_`t'_t`ter'
	}	
}	
	
foreach ter in "1" "2" "3"{
	foreach t in "7" "8" "12" {
		*log changes
		gen dl_nets_birth_`t'_t`ter' = (nets_birth_empchange_`t'_t`ter'/L`t'.nets_emp)*(dl_nets_emp_`t'/(exp(`t'*dl_nets_emp_`t'/100)-1))
		gen dl_nets_exp_`t'_t`ter' = (nets_exp_empchange_`t'_t`ter'/L`t'.nets_emp)*(dl_nets_emp_`t'/(exp(`t'*dl_nets_emp_`t'/100)-1))
		gen dl_nets_death_`t'_t`ter' = -(nets_death_empchange_`t'_t`ter'/L`t'.nets_emp)*(dl_nets_emp_`t'/(exp(`t'*dl_nets_emp_`t'/100)-1))
		gen dl_nets_con_`t'_t`ter' = -(nets_con_empchange_`t'_t`ter'/L`t'.nets_emp)*(dl_nets_emp_`t'/(exp(`t'*dl_nets_emp_`t'/100)-1))
		gen dl_nets_ext_`t'_t`ter' = dl_nets_birth_`t'_t`ter' - dl_nets_death_`t'_t`ter'
		gen dl_nets_int_`t'_t`ter' = dl_nets_exp_`t'_t`ter' - dl_nets_con_`t'_t`ter'
		gen dl_nets_cre_`t'_t`ter' = dl_nets_birth_`t'_t`ter' + dl_nets_exp_`t'_t`ter'
		gen dl_nets_des_`t'_t`ter' = dl_nets_death_`t'_t`ter' + dl_nets_con_`t'_t`ter'
	}
}	

foreach t in "7" "8" "12" {
	gen dl_nets_birth_`t' = dl_nets_birth_`t'_t1 + dl_nets_birth_`t'_t2 + dl_nets_birth_`t'_t3
	gen dl_nets_death_`t' = dl_nets_death_`t'_t1 + dl_nets_death_`t'_t2 + dl_nets_death_`t'_t3
	gen dl_nets_exp_`t' = dl_nets_exp_`t'_t1 + dl_nets_exp_`t'_t2 + dl_nets_exp_`t'_t3
	gen dl_nets_con_`t' = dl_nets_con_`t'_t1 + dl_nets_con_`t'_t2 + dl_nets_con_`t'_t3
	gen dl_nets_ext_`t' = dl_nets_ext_`t'_t1 + dl_nets_ext_`t'_t2 + dl_nets_ext_`t'_t3
	gen dl_nets_int_`t' = dl_nets_int_`t'_t1 + dl_nets_int_`t'_t2 + dl_nets_int_`t'_t3
	gen dl_nets_cre_`t' = dl_nets_cre_`t'_t1 + dl_nets_cre_`t'_t2 + dl_nets_cre_`t'_t3
	gen dl_nets_des_`t' = dl_nets_des_`t'_t1 + dl_nets_des_`t'_t2 + dl_nets_des_`t'_t3
}		
	
foreach ter in "1" "2" "3"{
	foreach t in "7" "8" "12" {
		gen dl_nets_emp_`t'_t`ter' = dl_nets_birth_`t'_t`ter' - dl_nets_death_`t'_t`ter' + dl_nets_exp_`t'_t`ter' - dl_nets_con_`t'_t`ter'
	}
}
	
	
*Generate YEAR and SECTOR-YEAR DUMMIES

qui tab year, gen(yeard)
gen sectors=sector1+2*sector2+3*sector3+4*sector4+5*sector5+6*sector6+7*sector7+8*sector8+9*sector9+10*sector10
gen sectoryear=ln(sectors+1)*ln(year)
qui tab sectoryear, gen(sectoryeard)

*Generate YEAR-MANUF-NON-MANUF dummies
gen bigsectoryear=(1+manuf)*year
qui tab bigsectoryear, gen(mannonmand)

* You could also add dummies in the regression by adding i.year#i.sectors

*Base year for aw weights (1992)

foreach b in "cbp" "nets"  {
	gen `b'_emp1992=`b'_emp
	replace `b'_emp1992=F.`b'_emp1992 if year==1991
	
	forvalues i = 1993/2011 {
		replace `b'_emp1992=L.`b'_emp1992 if year==`i'
	}
		
	gen `b'_emp1993=`b'_emp
	replace `b'_emp1993=F.`b'_emp1993 if year==1992
	replace `b'_emp1993=F.`b'_emp1993 if year==1991
		
	forvalues i = 1994/2012 {
		replace `b'_emp1993=L.`b'_emp1993 if year==`i'
	}
}
		
gen cbp_emp1991=cbp_emp
	
forvalues i = 1992/2011 {
	replace cbp_emp1991=L.cbp_emp1991 if year==`i'
}
			

*Create industry-level trade costs

foreach t in "7" "8" "12" {
	gen d_import_usch_`t'=(1/`t')*(l_import_usch-L`t'.l_import_usch)
	gen d_import_otch_`t'=(1/`t')*(l_import_otch-L`t'.l_import_otch)*(ratiorm9188)
}
	
	
*Generating zeros for direct import penetration measures in non-manufacturing
foreach t in "7" "8" "12" {
	replace d_import_usch_`t'=0 if manuf==0
	replace d_import_otch_`t'=0 if manuf==0
}


*Generating zeros for manuf-sector dummies in non-manufacturing industries
forvalues t = 1/10 {
	replace sector`t'=0 if manuf==0
}


estimates clear


	**************generating conditions and controls******************
	local window07 year==2007
	local window99 year==1999
	local window9211 year==1999 | year==2011
	local window9207 year==1999 | year==2007

	* Controls
	local time_controls yeard*
	local sector_controls sector1-sector10
	local sectoryear_controls sectoryeard*
	local bigsectoryear_controls mannonmand*
	local prod_controls "ind_prodwemp_1991 ind_lnavgw_1991 ind_capvadd_1991 ind_ci_1990 ind_htsh1_1990"
    local pretrend_controls "d_ind_shemp_7691 d_ind_lnavgw_7691"
	
	
	* Specify weighting and clustering
	gen sic3=int(sic87dd/10)
	local aw "[aw = nets_emp1992]"
	local vce "vce(cluster sic3)"
	local options "noconstant vce(cluster sic3)"
	local optionsxt "fe cluster(sic3)"
	
	* Varibles needed to calculate predicted employment losses
	foreach f in "nets_emp" "cbp_emp" {
		gen `f'_2011 = `f' if year == 2011
		gen `f'_2007 = `f' if year == 2007
		gen `f'_1999 = `f' if year == 1999
	}

	* Factor to undo annualization
	gen lambda_9211 = 100/(2011 - 1992) 
	gen lambda_9207 = 100/(2007 - 1992)
	gen lambda_9299 = 100/(1999 - 1992)
	gen lambda_9911 = 100/(2011 - 1999)
	gen lambda_9907 = 100/(2007 - 1999)

	*"T" means total annualized change
	gen Td_import_usch_9211=(1/19)*(l_import_usch-L19.l_import_usch)
	gen Td_import_usch_9207=(1/15)*(l_import_usch-L15.l_import_usch)
	gen Td_import_usch_9299=(1/7)*(l_import_usch-L7.l_import_usch)
	gen Td_import_usch_9911=(1/12)*(l_import_usch-L12.l_import_usch)
	gen Td_import_usch_9907=(1/8)*(l_import_usch-L8.l_import_usch)


	
	*Creating stacked variables for 1992-1999, 1999-2007

	foreach b in "cbp" "nets" {
		gen dl_`b'_emp_9207=dl_`b'_emp_8
		replace dl_`b'_emp_9207=dl_`b'_emp_7 if year==1999
	}
	
	foreach ter in "1" "2" "3"{
		gen dl_nets_emp_9207_t`ter' = dl_nets_emp_8_t`ter'
		replace dl_nets_emp_9207_t`ter' = dl_nets_emp_7_t`ter' if year==1999	
	}	
	
	foreach f in "nets_birth" "nets_death" "nets_exp" "nets_con" "nets_ext" "nets_int" "nets_cre" "nets_des" {	
		gen dl_`f'_9207 = dl_`f'_8
		replace dl_`f'_9207 = dl_`f'_7 if year==1999	
		
		foreach ter in "1" "2" "3"{
			gen dl_`f'_9207_t`ter' = dl_`f'_8_t`ter'
			replace dl_`f'_9207_t`ter' = dl_`f'_7_t`ter' if year==1999	
		}	
	}

	foreach f in "spread" {
		gen `f'_9207=`f'_8
		replace `f'_9207=`f'_7 if year==1999			
	}
		
	foreach k in "import"  {
		gen d_`k'_usch_9207=d_`k'_usch_8
		gen d_`k'_otch_9207=d_`k'_otch_8

		replace d_`k'_usch_9207=d_`k'_usch_7 if year==1999
		replace d_`k'_otch_9207=d_`k'_otch_7 if year==1999
	}




***REGRESSIONS

* Regressions with NETS total employment

foreach f in "nets_emp" {


	*Columns (1) - (4)
	eststo m1_`f':ivregress 2sls dl_`f'_9207  (d_import_usch_9207 = d_import_otch_9207) `time_controls' `aw' if manuf==1 & (`window9207') , `options'	

	eststo m2_`f':ivregress 2sls dl_`f'_9207_t1  (d_import_usch_9207 = d_import_otch_9207) `time_controls' `aw' if manuf==1 & (`window9207') , `options'	
	eststo m3_`f':ivregress 2sls dl_`f'_9207_t2  (d_import_usch_9207 = d_import_otch_9207) `time_controls' `aw' if manuf==1 & (`window9207') , `options'	
	eststo m4_`f':ivregress 2sls dl_`f'_9207_t3  (d_import_usch_9207 = d_import_otch_9207) `time_controls' `aw' if manuf==1 & (`window9207') , `options'	

	
	*Columns (5) - (8)
	eststo m5_`f':regress dl_`f'_9207  spread_9207 `time_controls' `aw' if manuf==1 & (`window9207') , `options'	

	eststo m6_`f':regress dl_`f'_9207_t1  spread_9207 `time_controls' `aw' if manuf==1 & (`window9207') , `options'	
	eststo m7_`f':regress dl_`f'_9207_t2  spread_9207 `time_controls' `aw' if manuf==1 & (`window9207') , `options'	
	eststo m8_`f':regress dl_`f'_9207_t3  spread_9207 `time_controls' `aw' if manuf==1 & (`window9207') , `options'	
	
}

* Regressions with Job Flows

foreach f in "nets_birth" "nets_death" "nets_exp" "nets_con" "nets_ext" "nets_int" "nets_cre" "nets_des" {
	

	*Columns (1) - (4)
	eststo m1_`f':ivregress 2sls dl_`f'_9207  (d_import_usch_9207 = d_import_otch_9207) `time_controls' `aw' if manuf==1 & (`window9207') , `options'	

	eststo m2_`f':ivregress 2sls dl_`f'_9207_t1  (d_import_usch_9207 = d_import_otch_9207) `time_controls' `aw' if manuf==1 & (`window9207') , `options'	
	eststo m3_`f':ivregress 2sls dl_`f'_9207_t2  (d_import_usch_9207 = d_import_otch_9207) `time_controls' `aw' if manuf==1 & (`window9207') , `options'	
	eststo m4_`f':ivregress 2sls dl_`f'_9207_t3  (d_import_usch_9207 = d_import_otch_9207) `time_controls' `aw' if manuf==1 & (`window9207') , `options'	


	*Columns (5) - (8)
	eststo m5_`f':regress dl_`f'_9207  spread_9207 `time_controls' `aw' if manuf==1 & (`window9207') , `options'	

	eststo m6_`f':regress dl_`f'_9207_t1  spread_9207 `time_controls' `aw' if manuf==1 & (`window9207') , `options'	
	eststo m7_`f':regress dl_`f'_9207_t2  spread_9207 `time_controls' `aw' if manuf==1 & (`window9207') , `options'	
	eststo m8_`f':regress dl_`f'_9207_t3  spread_9207 `time_controls' `aw' if manuf==1 & (`window9207') , `options'	

}


foreach f in "nets_emp" "nets_birth" "nets_death" "nets_exp" "nets_con" "nets_ext" "nets_int" "nets_cre" "nets_des" {

esttab m1_`f' m2_`f' m3_`f' m4_`f' m5_`f' m6_`f' m7_`f' m8_`f' using "`outdir'tab3.csv", b(%9.2f) se(%9.2f) star(* .10 ** .05 *** .01) replace
insheet using "`outdir'tab3.csv", comma clear
export excel "`outdir'tab3.xlsx", sheetreplace sheet(tab3_`f')

}

